<?php

/**
 * CoreFramework
 *
 * @package   CoreFramework
 * @author    Core Framework <hello@coreframework.com>
 * @copyright 2023 Core Framework
 * @license   EULA + GPLv2
 * @link      https://coreframework.com
 */

declare(strict_types=1);

namespace CoreFramework\App\Updater;

use CoreFramework\Common\Abstracts\Base;

/**
 * Class Updater
 *
 * @package CoreFramework\App\Updater
 * @since 1.0.0
 */
class Updater extends Base {

	/**
	 * Initialize the updater class.
	 */
	public function __construct() {
	}

	/**
	 * Activate the license.
	 *
	 * @return void
	 */
	public function activate() {
		$api_params = array(
			'edd_action' => 'activate_license',
			'license'    => 'free',
			'item_id'    => urlencode( strval( CORE_FRAMEWORK_FREE_ITEM_ID ) ),
			'url'        => home_url(),
		);

		$response = wp_remote_post(
			CORE_FRAMEWORK_EDD_STORE_URL,
			array(
				'timeout'   => 15,
				'sslverify' => false,
				'body'      => $api_params,
			)
		);

		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {
			if ( is_wp_error( $response ) ) {
				return false;
			}
		} else {
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			if ( false === $license_data->success ) {
				return false;
			}
		}

		update_option( 'core_framework_free_license', home_url(), false );
	}
}
